import React, { useState } from 'react';
import axios from '@/services/APIservices';

const ContactForm = ({ userID, postId, postUserName, postUserPhoto, postBy, propertyTitle, propertyCity, price, mainImg, developerPostPrice }) => {
  const [formData, setFormData] = useState({
    name: '',
    phoneNumber: '',
    emailId: '',
    agreeToContact: 0
  });

  const [submitStatus, setSubmitStatus] = useState({ 
    loading: false,
    error: null,
    success: false
  });

  // Function to construct the profile photo URL
  const getProfilePhotoUrl = (photoName) => {
    if (!photoName) return '/dashboard-profile.png'; // Fallback image
    return `http://localhost:8000/user-img/user-images/${photoName}`;
  };

  const handleInputChange = (e) => {
    const { name, value, type, checked } = e.target;
    setFormData(prevState => ({
      ...prevState,
      [name]: type === 'checkbox' ? (checked ? 1 : 0) : value
    }));
  };

  const handleSubmit = async (e) => {
    e.preventDefault();

    if (!formData.name || !formData.phoneNumber || !formData.emailId) {
      setSubmitStatus({
        loading: false,
        error: 'Please fill in all fields',
        success: false
      });
      setTimeout(() => setSubmitStatus(prevState => ({ ...prevState, error: null })), 2000);
      return;
    }

    const submissionData = {
      userID,
      postId,
      postUserName,
      postBy,
      postUserPhoto,
      propertyTitle,
      propertyCity,
      price,
      mainImg,
      developerPostPrice,
      ...formData
    };

    try {
      setSubmitStatus({
        loading: true,
        error: null,
        success: false
      });

      const response = await axios.post(`/api/public-inquiry/${userID}`, submissionData);

      setSubmitStatus({
        loading: false,
        error: null,
        success: true
      });

      setFormData({
        name: '',
        phoneNumber: '',
        emailId: '',
        agreeToContact: 0
      });

      console.log('Submission successful', response.data);

      setTimeout(() => setSubmitStatus(prevState => ({ ...prevState, success: false })), 5000);

    } catch (error) {
      setSubmitStatus({
        loading: false,
        error: error.response?.data?.message || 'An error occurred while submitting the form',
        success: false
      });

      console.error('Submission error', error);

      setTimeout(() => setSubmitStatus(prevState => ({ ...prevState, error: null })), 2000);
    }
  };

  return (
    <div className='bg-white flex flex-col gap-4 rounded-lg px-4 py-4 w-full max-w-md mx-auto sm:max-w-sm md:max-w-md lg:max-w-lg'>
      <div className='flex justify-between items-center'>
        <p className='text-xl font-semibold'>Contact Owner</p>
        <div className='text-white px-2 py-1 bg-brand rounded-lg font-semibold text-sm'>Verified</div>
      </div>

      <div className="flex flex-col sm:flex-row gap-4 items-center">
        <img
          src={getProfilePhotoUrl(postUserPhoto)}
          alt={`${postUserName}'s profile`}
          className='w-16 h-16 rounded-full object-cover self-center'
          onError={(e) => {
            e.target.onerror = null;
            e.target.src = '/dashboard-profile.png';
          }}
        />
        <div className='text-center sm:text-left'>
          <p className='text-xl font-semibold'>
            {postUserName.charAt(0).toUpperCase() + postUserName.slice(1)}
          </p>
        </div>
      </div>

      <p className='text-center sm:text-left'>Please share your contact</p>

      {submitStatus.error && (
        <div className='text-red-500 text-sm text-center'>
          {submitStatus.error}
        </div>
      )}

      {submitStatus.success && (
        <div className='text-green-500 text-sm text-center'>
          Your contact information has been submitted successfully!
        </div>
      )}

      <form onSubmit={handleSubmit} className='flex flex-col gap-3 w-full'>
        <input
          type="hidden"
          name="userID"
          value={userID}
          readOnly
          className='w-full p-2 border rounded'
        />
        <input
          type="text"
          name="name"
          placeholder="Name"
          value={formData.name}
          onChange={handleInputChange}
          className='w-full p-2 border rounded'
          required
        />
        <input
          type="tel"
          name="phoneNumber"
          placeholder="Phone Number"
          value={formData.phoneNumber}
          onChange={handleInputChange}
          className='w-full p-2 border rounded'
          required
        />
        <input
          type="email"
          name="emailId"
          placeholder="Email ID"
          value={formData.emailId}
          onChange={handleInputChange}
          className='w-full p-2 border rounded'
          required
        />

        <div className="flex items-center gap-2">
          <input
            type="checkbox"
            name="agreeToContact"
            checked={formData.agreeToContact === 1}
            onChange={handleInputChange}
          />
          <p className='text-sm'>I agree to be contacted by Jaminjaidad</p>
        </div>

        <button
          type="submit"
          disabled={submitStatus.loading}
          className='bg-brand py-2 text-white font-semibold rounded hover:bg-opacity-90 transition-colors w-full disabled:opacity-50'
        >
          {submitStatus.loading ? 'Submitting...' : 'Contact Seller'}
        </button>
      </form>
    </div>
  );
};

export default ContactForm;